@@ -8,7 +8,7 @@
 #' @return The list of Datasets that can be screened in DATSU with the IDs
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' getListQCChecks(145)
 #' getListQCChecks(145, "VE")
 #' }
@@ -30,12 +30,5 @@ getListQCChecks <- function(datasetverID, recordType = NULL) {
   # perform request
   out <- datsu_get(url)
 
-  # some formatting and mods
-  out$sqlText <- tolower(out$sqlText)
-  out$sqlText <- gsub("year[(]getdate[(][)][)]", 2022, out$sqlText)
-  message("year hard wired to 2022 for now")
-  out$sqlText <- gsub("len[(]", "length(", out$sqlText)
-  #out$sqlText <- gsub("isnull[(]", "ifnull(", out$sqlText)
-
   out
 }
